@@ -1,8 +1,8 @@
 package Bio::Graphics::Glyph::wiggle_whiskers;
 
 use strict;
-use base qw(Bio::Graphics::Glyph::wiggle_minmax
-            Bio::Graphics::Glyph::xyplot
+use base qw(Bio::Graphics::Glyph::wiggle_data
+            Bio::Graphics::Glyph::wiggle_xyplot
             );
 
 
@@ -57,16 +57,34 @@ sub my_options {
 	    'The color drawn from -stdev to min.'
 	],
 	graph_type => [
-	    ['boxes','whiskers'],
-	    'boxes',
-	    'Type of graph to generate. Options are "boxes" (for a barchart),',
-	    'or "whiskers" (for a whiskerplot showing mean, +/- stdev and max/min.'
+	    ['histogram','whiskers'],
+	    'histogram',
+	    'Type of graph to generate. Options are "histogram" (for a barchart),',
+	    'or "whiskers" (for a whiskerplot showing mean, +/- stdev and max/min.',
+	    'The deprecated "boxes" subtype is a synonym for "histogram."'
 	],
     }
 }
 
+sub color_series {
+    my $self = shift;
+    return $self->{color_series} if exists $self->{color_series};
+    return $self->{color_series} = $self->option('color_series');
+}
+
+sub overlaps {
+    my $self = shift;
+    return $self->{overlaps} if exists $self->{overlaps};
+    return $self->{overlaps} = $self->bump eq 'overlap';
+}
+
+sub pad_top {
+    my $self = shift;
+    return $self->Bio::Graphics::Glyph::wiggle_xyplot::pad_top;
+}
+
 sub extra_label_pad {
-    return 16
+    return 8
 }
 
 sub graph_type {
@@ -75,35 +93,41 @@ sub graph_type {
 
 sub glyph_subtype {
     my $self = shift;
-    return $self->option('glyph_subtype') || $self->option('graph_type') || 'boxes';
+    return $self->option('glyph_subtype') || $self->option('graph_type') || 'histogram';
 }
 
 sub mean_color {
     my $self = shift;
+    return $self->bgcolor if $self->color_series;
     return $self->color('mean_color') || $self->translate_color('black');
 }
 
 sub mean_color_neg {
     my $self = shift;
+    return $self->bgcolor if $self->color_series;
     return $self->color('mean_color_neg') || $self->mean_color;
 }
 
 sub stdev_color {
     my $self = shift;
+    return $self->bgcolor if $self->color_series;
     return $self->color('stdev_color') || $self->translate_color('grey');
 }
 
 sub stdev_color_neg {
     my $self = shift;
+    return $self->bgcolor if $self->color_series;
     return $self->color('stdev_color_neg') || $self->stdev_color;
 }
 sub max_color {
     my $self = shift;
+    return $self->bgcolor if $self->color_series;
     return $self->color('max_color') || $self->translate_color('lightgrey');
 }
 
 sub min_color {
     my $self = shift;
+    return $self->bgcolor if $self->color_series;
     return $self->color('min_color') || $self->max_color;
 }
 
@@ -132,8 +156,10 @@ sub draw {
   my ($scaled_min,$scaled_max);
   if ($rescale) {
       my $bound  = $self->z_score_bound;
-      $scaled_min = -$bound;
-      $scaled_max = +$bound;
+      $scaled_min = int(($min_score-$mean)/$stdev + 0.5);
+      $scaled_max = int(($max_score-$mean)/$stdev + 0.5);
+      $scaled_max = $bound  if $scaled_max > $bound;
+      $scaled_min = -$bound if $scaled_min < -$bound;
       $self->{_stdev}     = $stdev;
       $self->{_mean}      = $mean;
       $self->{_zfold}     = $bound;
@@ -173,10 +199,13 @@ sub draw {
   $self->_draw_scale($gd,$scale,$scaled_min,$scaled_max,$dx,$dy,$y_origin);
   $self->panel->endGroup($gd);
 
-  $self->draw_label(@_)       if $self->option('label');
+  $self->draw_label(@_)       if $self->option('label') or $self->record_label_positions;
   $self->draw_description(@_) if $self->option('description');
 
   $self->panel->endGroup($gd);
+
+  # inhibit the scale if we are non-bumping
+  $self->configure(-scale => 'none') if $self->overlaps;
 }
 
 sub _draw_whiskers {
@@ -190,6 +219,7 @@ sub _draw_whiskers {
     my $stdev_color_neg = $self->stdev_color_neg;
     my $max_color   = $self->max_color;
     my $min_color   = $self->min_color;
+    my $clip_color  = $self->clip_color;
 
     my $graph_type = $self->graph_type;
 
@@ -218,15 +248,26 @@ sub _draw_whiskers {
 	my $max_pos   = $self->score2position($max);
 	my $min_pos   = $self->score2position($min);
 
-	if ($graph_type eq 'boxes') {
+	my ($clip_top,$clip_bottom);
+	foreach (\$mean_pos,\$plus_one,\$minus_one,\$max_pos,\$min_pos) {
+	    if (int($$_) < $top - 2) {
+		$$_ = $top;
+		$clip_top++;
+	    } elsif (int($$_) > $bottom + 2) {
+		$$_ = $bottom;
+		$clip_bottom++;
+	    }
+	}
+
+	if ($graph_type =~ /histogram|boxes/) {
 	    if ($mean >= 0) {
-		$gd->line($pos,$origin,$pos,$mean_pos,$mean_color);
+		$gd->line($pos,$origin,$pos,$mean_pos,  $mean_color);
 		$gd->line($pos,$mean_pos,$pos,$plus_one,$stdev_color) if $mean_pos != $plus_one;
-		$gd->line($pos,$plus_one,$pos,$max_pos,$max_color)    if $plus_one != $max_pos;
+		$gd->line($pos,$plus_one,$pos,$max_pos, $max_color)   if $plus_one != $max_pos;
 	    } else {
-		$gd->line($pos,$origin,$pos,$mean_pos,$mean_color_neg);
-		$gd->line($pos,$mean_pos,$pos,$minus_one,$stdev_color_neg) if $mean_pos != $minus_one;
-		$gd->line($pos,$minus_one,$pos,$min_pos,$min_color)         if $minus_one != $min_pos;
+		$gd->line($pos,$origin,$pos,$mean_pos,   $mean_color_neg);
+		$gd->line($pos,$mean_pos,$pos,$minus_one,$stdev_color_neg) if $mean_pos  != $minus_one;
+		$gd->line($pos,$minus_one,$pos,$min_pos, $min_color)       if $minus_one != $min_pos;
 	    }
 	} 
 	else {
@@ -236,7 +277,10 @@ sub _draw_whiskers {
 	    $gd->line($pos,$mean_pos+1,$pos,$minus_one,$stdev_color)       if $minus_one != $mean_pos;
 	    $gd->line($pos,$minus_one+1,$pos,$min_pos,$min_color)          if $min_pos != $mean_pos;
 	}
-	
+
+# this tops off clipped peaks with a distinct color, but I just don't like how it looks
+	$gd->line($pos,$top-2,     $pos,$top,    $clip_color) if $clip_top;
+	$gd->line($pos,$bottom,$pos,$bottom+2, $clip_color)   if $clip_bottom;
     } continue {
 	$self->{flip} ? $pos-- : $pos++;
     }
